pub struct RandomnessRoundReceiverHandle { /* private fields */ }Implementations
Sourceimpl RandomnessRoundReceiverHandle
impl RandomnessRoundReceiverHandle
Sourcepub fn set_public_key(&self, vss_pk: G2Element)
pub fn set_public_key(&self, vss_pk: G2Element)
Sets the VSS public key for signature verification. Called by
RandomnessManager::advance_dkg when DKG completes.
Sourcepub fn clear_public_key(&self)
pub fn clear_public_key(&self)
Clears the VSS public key. Called at epoch start before the new DKG
completes. While the key is None, incoming randomness round signatues from consensus
accumulate in the bounded channel giving the opportunity to buffer them until DKG completes.
Sourceimpl RandomnessRoundReceiverHandle
impl RandomnessRoundReceiverHandle
pub fn new_for_testing() -> Arc<Self>